# -*- coding:utf-8 -*-
import os, ctypes, subprocess
from security_module import SecurityModule
from utils import create_file

from log import log_debug, log_error

RELABEL_FILE="/.exectl"

class ExectlModule(SecurityModule):
	status_desc = {
		"0": "关闭",
		"2": "启用(enabled)",
		"4": "启用(softmode)",
	}
	def __init__(self):
		SecurityModule.__init__(self, "exectl")

	@staticmethod
	def getstatus():
		try:
			kyseclib = ctypes.cdll.LoadLibrary("libkysec.so.0")
		except OSError as e:
			return 0
		else:
			return kyseclib.kysec_getstatus()

	@classmethod
	def do_enable(self):
		result, error = create_file(RELABEL_FILE)
		if not result:
			return (False, "无法创建标记文件 '%s'"%RELABEL_FILE)
		else:
			return (True, None)

	@classmethod
	def do_disable(self):
		try:
			if os.path.exists(RELABEL_FILE):
				os.unlink(RELABEL_FILE)
		except Exception as e:
			error="无法删除标记文件 '%s'"%RELABEL_FILE
			log_error("%s: %s"%(error, str(e)))
			return (False, error)
		return (True, None)
