#!/usr/bin/python3
# -*- coding:utf-8 -*-

from modules_desc import security_modules
from utils import print_err, check_package, check_ksymbol
from log import log_error, log_debug

class SecurityModule:
	status_desc={ "0": "关闭", "1": "启用" }
	def __init__(self, name):
		self.module_desc=security_modules[name]	
		self.name=security_modules[name]["name"]
		self.desc=security_modules[name]["desc"]

	def check_kernel(self):
		'''
		检查当前内核配置能否满足该安全模块, 该检查是
		通过内核符号表进行的

		返回值:
		  检查成功返回True, 否则返回False
		'''
		log_debug("检查内核符号表: '%s'\n"%self.module_desc["ksymbol"])
		result, error = check_ksymbol(self.module_desc["ksymbol"])
		if not result and error:
			log_error("获取内核配置信息时出错：%s\n"%error)
		
		return result

	def check_packages(self, modules):
		'''
		检查当前系统是否安装了启用该安全模块所需的软件包

		参数：
		   modules: 要启用的安全模块列表

		返回值:
		   检查成功返回(True, None), 否则返回(False, 未安装的包列表)
		'''
		pkg_unmatched = []
		for item in self.module_desc["packages"]:
			log_debug("检查软件包 '%s' ...\n"%item["name"])
			if not check_package(item["name"], item["modified"]):
				pkg_unmatched.append(item["name"])
				
		if not len(pkg_unmatched):
			return (True, None)

		return (False, pkg_unmatched)

	@staticmethod
	def getstatus_desc(status_desc, status):
		'''
		获取安全模块状态的文本描述

		参数:
		  status_desc: 文本描述列表
		  status: 要转换的模块状态

		返回值:
		  返回status_desc中status对应的文本描述，若status未找到
		  则返回“未知"
		'''
		status = str(status)
		if status in status_desc:
			return status_desc[status]
		return "未知"

	def check_system(self, next_state):
		return (True, None)

	def pre_enable(self):
		return (True, None)

	def pre_disable(self):
		return (True, None)

	def post_enable(self):
		return (True, None)

	def post_disable(self):
		return (True, None)

	def do_enable(self):
		return (True, None)

	def do_disable(self):
		return (True, None)
