# -*- coding:utf-8 -*-
import os, subprocess, re
import tempfile
import shutil

from utils import print_err
import subprocess
from log import log_debug, log_error, LogManager

KYSEC_U_SERIAL=1

grub_key="GRUB_CMDLINE_LINUX_SECURITY"
grub_path="/etc/default/grub"

def update_boot_params(params):
	'''
	更新Grub启动配置, 该函数会先修改/etc/default/grub配置
	然后调用update-grub命令更新启动配置。

	参数:
	  params: 安全启动参数，格式为字符串

	返回值:
	  操作成功返回(True, None)，失败返回（False, 失败信息)
	'''
	try:
		f = open(grub_path, "r")		
	except Exception as e:
		log_error("Can't open grub configuration file for read: %s"%str(e))
		return (False, "无法打开grub默认配置")

	try:
		fd, temp_path = tempfile.mkstemp(prefix="grub.")
		temp = open(temp_path, "w")
	except Exception as e:
		f.close()
		log_error("Can't create temp file for write: %s"%str(e))
		return (False, "无法写入临时文件")

	exists=False
	while True:
		line = f.readline()
		if not len(line):
			break
		if not line.startswith("%s="%grub_key):
			temp.write(line)
			continue

		temp.write("%s=\"%s\"\n"%(grub_key, params))
		exists = True

	# grub security args not found, just append
	if not exists:
		temp.write("%s=\"%s\"\n"%(grub_key, params))

	f.close() 
	temp.close()

	try:
		shutil.move(temp_path, grub_path)
		log_debug("Updating boot configuration file...")
		if KYSEC_U_SERIAL:
			subprocess.check_call(["update-grub"], stdout=LogManager.getfd(), stderr=LogManager.getfd(), env=os.environ)
		else:
			retcode, grub_cfg = subprocess.getstatusoutput("find /boot -name grub.cfg")
			if retcode == 0:
				for cfg in grub_cfg.split('\n'):
					args = "grub2-mkconfig -o %s"%cfg
					subprocess.check_call(args, stdout=LogManager.getfd(), stderr=LogManager.getfd(), shell=True, env=os.environ)
			else:
				args = "grub2-mkconfig -o /boot/grub2/grub.cfg"
				subprocess.check_call(args, stdout=LogManager.getfd(), stderr=LogManager.getfd(), shell=True, env=os.environ)

	except subprocess.CalledProcessError as e:
		if KYSEC_U_SERIAL:
			log_error("failed to call update-grub: %s"%str(e))
			return (False, "运行update-grub命令时出错")
		else:
			log_error("failed to call grub2-mkconfig: %s"%str(e))
			return (False, "运行grub2-mkconfig命令时出错")
	except Exception as e:
		log_error("can't save grub configuration: %s"%str(e))
		return (False, "保存grub配置文件时出错")

	return (True, None)
